# comment_mail-smtp.rb $Revision: 1.10 $
#
# SMTPץȥȤäƥĥåߤ᡼Τ餻
#   ư
#
# Options:
#   ̤Ǥ(ĥåߥ᡼ϥץ饰):
#     @options['comment_mail.enable']
#          ᡼뤫ɤꤹ롣true()false(ʤ)
#          ̵false
#     @options['comment_mail.header']
#          ᡼Subject˻Ȥʸ󡣿ʬʤ褦˻ꤹ롣
#          ºݤSubjectϡֻʸ:-1פΤ褦ˡդȥֹ椬
#          դʸˡ%³ѻä硢
#          եեޥåȻ򸫤ʤĤޤաפʬ
#          ưŪղäʤʤ(ֹղä)
#          ̵ˤ϶ʸ
#     @options['comment_mail.receivers']
#          ᡼륢ɥ쥹ʸ󡣥ޤǶڤäʣǤ롣
#          ̵ˤɮԤΥɥ쥹ˤʤ롣
#  
#   tdiary.confǤΤ߻Ǥ:
#     @options['comment_mail.smtp_host']
#     @options['comment_mail.smtp_port']
#          줾졢᡼˻ȤSMTPФΥۥ̾ȥݡֹ档
#          ̵Ϥ줾'localhost'פȡ25ס
#
# Copyright (c) 2003 TADA Tadashi <sho@spc.gr.jp>
# You can distribute this file under the GPL.
#
def comment_mail( text, to )
	begin
		require 'net/smtp'
		host = @conf['comment_mail.smtp_host'] || 'localhost'
		port = @conf['comment_mail.smtp_port'] || 25
		Net::SMTP.start( host, port ) do |smtp|
			smtp.send_mail( text, @conf.author_mail.untaint, to )
		end
	rescue
		$stderr.puts $!
	end
end

add_update_proc do
	comment_mail_send if @mode =~ /^(comment|trackbackreceive|pingbackreceive)$/
end

add_conf_proc( 'comment_mail', comment_mail_conf_label, 'tsukkomi' ) do
	comment_mail_basic_setting
	comment_mail_basic_html
end
